"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const BinaryOperatorNode_1 = tslib_1.__importDefault(require("./BinaryOperatorNode"));
/**
 * Represents a logical AND operation between two nodes.
 *
 * This is used in queries which resemble the following:
 *
 *   (PartitionKey eq 'foo') and (RowKey eq 'bar')
 *
 * In this case, the `AndNode` would be the root node, with the left and right nodes
 * corresponding to `(PartitionKey eq 'foo')` and `(RowKey eq 'bar')`, respectively.
 */
class AndNode extends BinaryOperatorNode_1.default {
    get name() {
        return `and`;
    }
    evaluate(context) {
        return this.left.evaluate(context) && this.right.evaluate(context);
    }
}
exports.default = AndNode;
//# sourceMappingURL=AndNode.js.map