"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const ValueNode_1 = tslib_1.__importDefault(require("./ValueNode"));
/**
 * Represents a constant value which should be decoded from its `hex` representation
 * and encoded as `base64` to match the underlying table storage format.
 *
 * This is used to hold binary values that are provided in the query (using the `binary'...'` syntax)
 * and is used to ensure that these values are evaluated against their normalized base64 format. For
 * example, the query `PartitionKey eq binary'0011'` would contain a `BinaryNode` with the value `0x0011`.
 */
class BinaryNode extends ValueNode_1.default {
    get name() {
        return "binary";
    }
    evaluate(_context) {
        return Buffer.from(this.value, "hex").toString("base64");
    }
}
exports.default = BinaryNode;
//# sourceMappingURL=BinaryDataNode.js.map