"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Represents a constant value which is stored in its underlying JavaScript representation.
 *
 * This is used to hold boolean, number, and string values that are provided in the query.
 * For example, the query `PartitionKey eq 'foo'` would contain a `ConstantNode` with the value `foo`.
 */
class ConstantNode {
    constructor(value) {
        this.value = value;
    }
    get name() {
        return "constant";
    }
    evaluate(_context) {
        return this.value;
    }
    toString() {
        return JSON.stringify(this.value);
    }
}
exports.default = ConstantNode;
//# sourceMappingURL=ConstantNode.js.map