"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Represents a unary "not" operation within the query.
 *
 * This is used in queries which resemble the following:
 *
 *   not (PartitionKey eq 'foo')
 *
 * In this case, the `NotNode` would be the root node, with the right node
 * corresponding to `(PartitionKey eq 'foo')`. As a unary operator, there
 * is no left node.
 */
class NotNode {
    constructor(right) {
        this.right = right;
    }
    get name() {
        return "not";
    }
    evaluate(context) {
        return !this.right.evaluate(context);
    }
    toString() {
        return `(${this.name} ${this.right.toString()})`;
    }
}
exports.default = NotNode;
//# sourceMappingURL=NotNode.js.map